@@ -17,7 +17,6 @@ import logging as log
 import traceback
 from typing import Type
 
-from hspylib.core.tools.commons import syserr
 from hspylib.core.tools.preconditions import check_not_none
 
 
@@ -40,8 +39,7 @@ class Singleton(type):
                 log.debug('Created a new Singleton instance: %s.%s', cls.__module__, cls.__name__)
             except Exception as err:  # pylint: disable=broad-except
                 log.error(traceback.format_exc())
-                syserr(traceback.format_exc())
-                print(err)
+                raise err from err
 
         return cls._instances[cls]
 
